<?php
/**
 * Project: sURI :: Secure URI<br>
 * File:    sURI.php
 *
 * sURI 패키지는 동적 one time query string을 생성할 수 있도록 한다.
 *
 * @category   HTML
 * @package    sURI
 * @author     JoungKyun.Kim <http://oops.org>
 * @copyright  (c) 2009 JoungKyun.Kim
 * @license    BSD
 * @version    $Id: sURI.php 49 2012-09-09 18:57:02Z oops $
 * @link       http://pear.oops.org/package/sURI
 * @since      File available since Release 0.1
 * @filesource
 */

/**
 * import sURI_Parser class
 */
require_once 'sURI/Parser.php';
sURI_Parser::magic_quotes_gpc_off ();

/**
 * Secure URI의 기본 클래스
 *
 * sURI 패키지는 동적 one time query string을 생성한다.
 *
 * @package sURI
 */
class sURI extends sURI_Parser {
	// {{{ properties
	/**#@+
	 * HTML version constants
	 */
	const HTML2   =  0;
	const HTML3   =  1;
	const HTML4   =  2;
	const HTML41  =  3;
	const HTML5   =  4;
	const XHTML10 = 10;
	const XHTML11 = 11;
	const XHTML12 = 12;
	const XHTML13 = 13;
	/**#@-*/

	/**#@+
	 * @access public
	 */
	/**
	 * sURI 에러 메시지
	 * @var    string
	 */
	public $errstring;
	/**
	 * HTML 버전
	 *
	 * 다음의 상수값을 이용한다.
	 *
	 * sURI::HTML2 sURI::HTML3 sURI::HTML4 sURI::HTMl41 sURI::HTML5
	 * sURI::XHTML10 sURI::XHTML11 sURI::XHTML12 sURI::XHTML13
	 */
	public  $htmlver;
	/**
	 * 문자셋
	 * @var string
	 */
	public  $charset;
	/**
	 * 내부 사용 변수
	 * @var string
	 */
	public $xhtmlclose;
	/**
	 * 내부 사용 변수
	 * @var integer
	 */
	public $urlencode;
	/**
	 * 내부 사용 변수
	 * @var integer
	 */
	public $eprefix = 0;

	/**
	 * 내부 사용 변수
	 * @var boolean
	 */
	public $legacy = false;
	/**
	 * 내부 사용 변수
	 * @var integer
	 */
	public $hashtype = 0;
	/**
	 * 내부 사용 변수
	 * @var boolean
	 */
    public $allow_url_block = true;
	/**
	 * 내부 사용 변수
	 * @var array
	 */
	public $allow_url_blocks = array ();
	/**#@-*/
	// }}}

	// {{{ sURI::__construct ($htmlver = HTML41, $charset = 'utf-8')
	/**
	 * sURI class 초기화
	 *
	 * @access public
	 * @return void
	 * @param int (optional) 생성할 코드의 HTML 버전. 기본값은 HTML41
	 * @param string (optional) 생성할 코드의 문자셋. 기본값은 utf-8
	 */
	function __construct ($htmlver = HTML41, $charset = 'utf-8') {
		$this->set_xhtml ($htmlver);
		$this->set_urlencode ();
		$this->charset = $charset;
	}
	// }}}

	// {{{ sURI::set_xhtml ($value = HTML41)
	/**
	 * XHTML close tag를 설정
	 *
	 * @param integer (optional) HTML 버전을 지정
	 * @access public
	 * @return void
	 */
	function set_xhtml ($value = self::HTML41) {
		$this->htmlver = $value;
		$this->xhtmlclose = ( $value >= self::XHTML10 ) ? ' /' : '';
	}
	// }}}

	// {{{ sURI::set_hash_type ($type = false)
	/**
	 * hash 형식의 유효성 확인
	 *
	 * @access public
	 * @return void
	 */
	function set_hash_type ($type = false) {
		if ( $type !== false ) {
			if ( $type >= $GLOBALS['hashno'] ) {
				echo ('ERROR: Unsupported Hash Type');
				exit;
			}
			$this->hashtype = $type;
			return;
		}

		if ( $_GET['hashtype'] )
			$_htype = $_GET['hashtype'];
		else if ( $_POST['hashtype'] )
			$_htype = $_POST['hashtype'];

		if ( is_numeric ($_htype) && $_htype < $GLOBALS['hashno'] )
			$this->hashtype = $_htype;
	}
	// }}}

	// {{{ (void) sURI::set_urlencode ($v = false)
	/**
	 * URL encoding을 할지 여부를 결정.
	 *
	 * @access public
	 * @return void
	 * @param bool $value (optional) true로 설정하면 url 인코딩을 한다.
	 *                    기본값은 false
	 */
	function set_urlencode ($v = false) {
		$this->urlencode = $v;
	}
	// }}}

	// {{{ (void) sURI::set_allow_block_url ($v = false)
	/**
	 * 지정된 블럭에 대해서 htmlspecialchars 변환을 하지 않음
	 *
	 * @access public
	 * @return void
	 * @param array (optional)
	 */
	function set_allow_url_block ($v = null) {
		if ( is_array ($v) ) {
			$this->allow_url_block = true;
			$this->allow_url_blocks = $v;
			return;
		}

		$this->allow_url_block = false;
	}
	// }}}

	// {{{ (void) sURI::set_legacy ($v = true)
	/**
	 * 기존 URL 매개변수 형식을 허가
	 *
	 * @param bool $value (optional) 기본값 true.
	 * @access public
	 * @return void
	 */
	function set_legacy ($v = true) {
		$this->legacy = $v;
	}
	// }}}

	// {{{ (void) sURI::set_error ($value = null)
	/**
	 * 에러 메시지를 class error api에 저장
	 *
	 * @access public
	 * @return void
	 * @param string 저장할 에러 메시지
	 */
	function set_error ($value = null) {
		if ( ! trim ($value) )
			return;

		$rpx = $this->eprefix + 8;
		$trace = debug_backtrace ();

		/*
		echo "<pre>";
		print_r ($trace);
		exit;
		 */

		$this->errstring = sprintf (
			"%-{$prx}s : %s line %d\n%-{$prx}s : %s\n%-{$prx}s : %s\n",
			'FILE', $trace[0]['file'], $trace[0]['line'],
			'Function', $trace[1]['class'] ?
						$trace[1]['class'] . '::' . $trace[1]['function'] :
						$trace[1]['function'],
			'Message', $value
		);
	}
	// }}}

	// {{{ (void) sURI::__destructor (void)
	/**
	 * @access public
	 * @return void
	 */
	function __destruct () { }
	// }}}
}
?>
